@@ -12,24 +12,26 @@ class RemoteAttribute(CommNode, NamedNode):
         name,
         summary,
         dtype,
-        c_getter=None,
-        c_setter=None,
+        getter_name=None,
+        setter_name=None,
         unit=None,
         rst_target=None,
         ep_id=-1,
+        dynamic_value=False,
     ):
         CommNode.__init__(self)
         NamedNode.__init__(self, name)
         self.summary = summary
         self.dtype = dtype
         self.unit = unit
-        self.c_getter = c_getter
-        self.c_setter = c_setter
+        self.getter_name = getter_name
+        self.setter_name = setter_name
         self.rst_target = rst_target
         self.ep_id = ep_id
+        self.dynamic_value = dynamic_value
 
     def get_value(self):
-        assert self.c_getter
+        assert self.getter_name, "No getter function available"
         self.channel.send([], self.ep_id)
         data = self.channel.recv(self.ep_id)
         value, *_ = self.channel.serializer.deserialize(data, self.dtype)
@@ -39,7 +41,11 @@ class RemoteAttribute(CommNode, NamedNode):
             return value
 
     def set_value(self, __value):
-        assert self.c_setter
+        assert self.setter_name, "No setter function available"
+        try:
+            __value = __value.to(self.unit).magnitude
+        except AttributeError:
+            pass
         data = self.channel.serializer.serialize([__value], self.dtype)
         self.channel.send(data, self.ep_id)
 
@@ -49,4 +55,3 @@ class RemoteAttribute(CommNode, NamedNode):
             self.dtype.nickname,
             self.get_value(),
         )
-
