@@ -1,6 +1,6 @@
 import os
 from jinja2 import Environment, PackageLoader, select_autoescape
-from avlos.generators.filters import avlos_endpoints, avlos_bitmask_eps, as_include
+from avlos.generators.filters import avlos_endpoints, avlos_bitmask_eps, as_include, file_from_path
 
 env = Environment(loader=PackageLoader("avlos"), autoescape=select_autoescape())
 
